==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_buildsample.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// setrandvar_buildsample ( token , token2 )
//   build a sampling from another set
// setrandvar_buildsample ( token , name , np )
//   build a sampling with sampling method "name" and np samples
// setrandvar_buildsample ( token , name , np , ne )
//   build a sampling with sampling method "name" and np samples, with selected ne samples
//   name = "MonteCarlo"
//   name = "Lhs"
//   name = "QmcSobol"
//   name = "Quadrature"
//   name = "Petras"
//   name = "SmolyakGauss"
//   name = "SmolyakTrapeze"
//   name = "SmolyakFejer"
//   name = "SmolyakClenshawCurtis"

//
int sci_setrandvar_buildsample (char *fname)
{
	int token;
	double * mydata = NULL;
	SetRandomVariable * srv = NULL;
	SetRandomVariable * srv2 = NULL;
	char * name = NULL;
	int np;
	string stringname;
	int ne;
	int token2;

	CheckRhs(2,4) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , & token );
	if ( (Rhs == 2) ) {
		nisp_GetOneInteger ( fname , 2 , &token2 );
	} else {
		nisp_GetOneChar ( fname , 2 , &name );
		nisp_GetOneInteger ( fname , 3 , &np );
		if ( (Rhs == 4) ) {
			nisp_GetOneInteger ( fname , 4 , &ne );
		}
	}
	nisp_token2Setrandvar ( fname , 1 , token , &srv );
	if ( (Rhs == 2) ) 
	{
		nisp_token2Setrandvar ( fname , 2 , token2 , &srv2 );
		srv->BuildSample ( srv2 );
	}
	else if ( (Rhs == 3) ) 
	{
		stringname.assign(name);
		srv->BuildSample ( stringname , np );
	}
	else if ( (Rhs == 4) ) 
	{
		stringname.assign(name);
		srv->BuildSample ( stringname , np , ne );
	}
	nisp_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_buildsample.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// setrandvar_buildsample ( token , token2 )
//   build a sampling from another set
// setrandvar_buildsample ( token , name , np )
//   build a sampling with sampling method "name" and np samples
// setrandvar_buildsample ( token , name , np , ne )
//   build a sampling with sampling method "name" and np samples, with selected ne samples
//   name = "MonteCarlo"
//   name = "Lhs"
//   name = "QmcSobol"
//   name = "Quadrature"
//   name = "Petras"
//   name = "SmolyakGauss"
//   name = "SmolyakTrapeze"
//   name = "SmolyakFejer"
//   name = "SmolyakClenshawCurtis"

//
int sci_setrandvar_buildsample (char *fname)
{
	int token;
	double * mydata = NULL;
	SetRandomVariable * srv = NULL;
	SetRandomVariable * srv2 = NULL;
	char * name = NULL;
	int np;
	int ne;
	int token2;

	CheckRhs(2,4) ;
	CheckLhs(0,1) ;
	nispgw_gettoken ( fname , 1 , & token );
	if ( (Rhs == 2) ) {
		nispgw_GetOneInteger ( fname , 2 , &token2 );
	} else {
		nispgw_GetOneChar ( fname , 2 , &name );
		nispgw_GetOneInteger ( fname , 3 , &np );
		if ( (Rhs == 4) ) {
			nispgw_GetOneInteger ( fname , 4 , &ne );
		}
	}
	nispgw_token2Setrandvar ( fname , 1 , token , &srv );
	if ( (Rhs == 2) ) 
	{
		nispgw_token2Setrandvar ( fname , 2 , token2 , &srv2 );
		srv->BuildSample ( srv2 );
	}
	else if ( (Rhs == 3) ) 
	{
		srv->BuildSample ( name , np );
	}
	else if ( (Rhs == 4) ) 
	{
		srv->BuildSample ( name , np , ne );
	}
	nispgw_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */
